# SLD : S3

Structure de la liste des dossiers S3

    Project/
    Project/src/
    Project/src/main.py
    Project/src/utils.py
    Project/src/__init__.py
    Project/tests/
    Project/tests/test_main.py
    Project/tests/test_utils.py
    Project/data/
    Project/data/raw/
    Project/data/raw/data1.csv
    Project/data/raw/data2.csv
    Project/data/processed/
    Project/data/processed/data1_processed.csv
    Project/data/processed/data2_processed.csv
    Project/docs/
    Project/docs/README.md
    Project/docs/CHANGELOG.md
    Project/requirements.txt